%define i18n_version	1.99.0

Name:		avogadro2
Version:	1.99.0
Release:	%mkrel 2
Summary:	An advanced molecular editor
License:	BSD
Group:		Sciences/Chemistry
URL:		https://www.openchemistry.org/projects/avogadro2/
Source0:	https://github.com/OpenChemistry/avogadroapp/archive/%{version}/avogadroapp-%{version}.tar.gz
Source1:	https://github.com/OpenChemistry/avogadro-i18n/archive/%{i18n_version}/avogadro-i18n-%{i18n_version}.tar.gz
BuildRequires:	cmake
BuildRequires:	doxygen
BuildRequires:	hdf5-devel
BuildRequires:	cmake(AvogadroLibs) >= %{version}
BuildRequires:	cmake(MoleQueue)
BuildRequires:	pkgconfig(eigen3)
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(Qt5Concurrent)
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Help)
BuildRequires:	pkgconfig(Qt5Network)
BuildRequires:	pkgconfig(Qt5OpenGL)
BuildRequires:	pkgconfig(Qt5Widgets)

Requires:	avogadrolibs
Requires:	openbabel
Requires:	python%{python3_pkgversion}

%description
Avogadro is an advanced molecular editor designed for cross-platform use in
computational chemistry, molecular modeling, bioinformatics, materials science,
and related areas. It offers flexible rendering and a powerful plugin
architecture. The code in this repository is a rewrite of Avogadro with source
code split across a libraries repository and an application repository. Core
features and goals of the Avogadro project:

  * Open source distributed under the liberal 3-clause BSD license
  * Cross platform with nightly builds on Linux, Mac OS X and Windows
  * Intuitive interface designed to be useful to whole community
  * Fast and efficient embracing the latest technologies
  * Extensible, making extensive use of a plugin architecture
  * Flexible supporting a range of chemical data formats and packages

%prep
%setup -q -n avogadroapp-%{version} -a1
%autopatch -p1

# help cmake to find translations
ln -s ${PWD}/avogadro-i18n-%{i18n_version}/ ../avogadro-i18n

%build
%cmake_qt5 \
	-DENABLE_TESTING:BOOL=OFF \
	-DCMAKE_SKIP_RPATH:BOOL=ON \
	-DBUILD_DOCUMENTATION:BOOL=ON

%cmake_build

%install
%cmake_install

rm -rf %{buildroot}%{_datadir}/doc

# more icons
for i in 64 128 256 512; do
	install -Dpm 644 avogadro/icons/%{name}_${i}.png %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps/%{name}.png
done

%files
%doc CONTRIBUTING.md README.md
%license LICENSE
%{_bindir}/avogadro2
%dir %{_datadir}/avogadro2
%dir %{_datadir}/avogadro2/i18n
%{_datadir}/avogadro2/i18n/avogadroapp-*.qm
%{_datadir}/avogadro2/i18n/avogadrolibs-*.qm
%{_datadir}/applications/avogadro2.desktop
%{_datadir}/pixmaps/avogadro2.png
%{_iconsdir}/hicolor/*/apps/avogadro2.png
%{_metainfodir}/avogadro2.appdata.xml


%changelog
* Sun Feb 18 2024 daviddavid <daviddavid> 1.99.0-2.mga10
+ Revision: 2042384
- add missing runtime dependency on avogadrolibs

* Mon Feb 12 2024 daviddavid <daviddavid> 1.99.0-1.mga10
+ Revision: 2040647
- new version: 1.99.0

* Fri Nov 03 2023 daviddavid <daviddavid> 1.98.1-1.mga10
+ Revision: 2003833
- new version: 1.98.1

* Sat Aug 13 2022 neoclust <neoclust> 1.97.0-1.mga9
+ Revision: 1877277
- New version 1.97.0
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild
+ mrambo3501 <mrambo3501>
- revert the rpath check disable

* Wed Mar 09 2022 mrambo3501 <mrambo3501> 1.93.0-4.mga9
+ Revision: 1790118
- disable rpath checking

* Wed Dec 16 2020 umeabot <umeabot> 1.93.0-3.mga8
+ Revision: 1658146
- Rebuild for new Qt5

* Fri Feb 21 2020 umeabot <umeabot> 1.93.0-2.mga8
+ Revision: 1547768
- Mageia 8 Mass Rebuild

* Sun Feb 09 2020 daviddavid <daviddavid> 1.93.0-1.mga8
+ Revision: 1488257
- new version: 1.93.0
+ wally <wally>
- build with new cmake macros

* Sat Mar 30 2019 umeabot <umeabot> 1.91.0-3.mga7
+ Revision: 1381297
- Qt5 Rebuild

* Fri Sep 21 2018 umeabot <umeabot> 1.91.0-2.mga7
+ Revision: 1295202
- Mageia 7 Mass Rebuild

* Sat Aug 25 2018 daviddavid <daviddavid> 1.91.0-1.mga7
+ Revision: 1254358
- new version: 1.91.0

* Sat Jun 02 2018 daviddavid <daviddavid> 1.90.0-2.mga7
+ Revision: 1233625
- add patch to fix build with new Qt5 >= 5.11.0

* Sat Dec 16 2017 daviddavid <daviddavid> 1.90.0-1.mga7
+ Revision: 1182774
- initial package avogadro2 (mga#22188)

